@@ -1,15 +1,15 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1514 2016-11-12 03:23:26Z willem $
+# $Id: DNS.pm 1522 2016-12-23 11:31:34Z willem $
 #
 BEGIN {
 	require 5.004_04;
 	require vars;
 	'vars'->import(qw($VERSION $SVNVERSION));
-	$VERSION    = '1.06_05';
+	$VERSION    = '1.06_06';
 	$VERSION    = eval $VERSION;
-	$SVNVERSION = (qw$LastChangedRevision: 1514 $)[1];
+	$SVNVERSION = (qw$LastChangedRevision: 1522 $)[1];
 }
 
 
@@ -569,7 +569,7 @@ See L<Net::DNS::Update> for an example of performing dynamic updates.
     my $res    = Net::DNS::Resolver->new;
     my $socket = $res->bgsend("host.example.com");
 
-    until ($res->bgisready($socket)) {
+    while ( $res->bgbusy($socket) ) {
 	# do some work here while waiting for the answer
 	# ...and some more here
     }
